@@ -1,9 +1,14 @@
-from .geometry import *
-from .query import *
-from .fit import *
-
 import pkg_resources
 
+from .fit import *
+from .plane import *
+from .frame import *
+from .point import *
+from .quaternion import *
+from .query import *
+from .rotation import *
+from .vector import *
+
 __version__ = pkg_resources.get_distribution("geo3d").version
 
 
