@@ -1,12 +1,12 @@
 import numpy as np
-
-from .geometry import Frame, MultipleVectorLike, Point, norm_L2, VectorLike, Plane
-from .linalg import dot_vec_vec, norm_L2
-
 from scipy.optimize import minimize
 from scipy.spatial.transform import Rotation as R
 
-from typing import Sequence
+from .frame import Frame
+from .linalg import dot_vec_vec, norm_L2
+from .plane import Plane
+from .point import Point
+from .types import MultipleVectorLike, VectorLike
 
 
 def distance_between_points(pointA: VectorLike, pointB: VectorLike) -> float:
@@ -102,4 +102,4 @@ def minimize_points_to_points_distance(
     if return_report:
         return t, m
     else:
-        return t
\ No newline at end of file
+        return t
