@@ -2,6 +2,7 @@ from geo3d import Vector, Point, express_vector_in_frame
 import numpy as np
 import pytest
 
+
 def test_vector_from_array():
     p = Vector([1, 2, 3])
     assert p[2] == 3
@@ -46,16 +47,16 @@ def test_express_vector_in_frame(example_frames):
     v0 = (1, 3, 0)
     v1 = (2.82843, -1.41421, 0)
 
-    assert Vector(v0).express_in_frame(
+    res0 = Vector(v0).express_in_frame(
         fa, original_frame=fb
-    ).as_array() == pytest.approx(v1, abs=1e-4)
+    )
+    assert res0.as_array() == pytest.approx(v1, abs=1e-4)
+    assert isinstance(res0._a, np.ndarray)
 
     assert express_vector_in_frame(
         v0, fa, original_frame=fb
     ).as_array() == pytest.approx(v1, abs=1e-4)
 
-    assert Vector(v0).express_in_frame(
-        fa, original_frame=fb
-    ) == Vector(v0).express_in_frame(
-        fa.express_in_frame(fb)
-    )
+    assert Vector(v0).express_in_frame(fa, original_frame=fb) == Vector(
+        v0
+    ).express_in_frame(fa.express_in_frame(fb))
